summaryrefslogtreecommitdiff
path: root/src
diff options
context:
space:
mode:
authorKay Sievers <kay.sievers@vrfy.org>2010-09-28 11:51:24 +0200
committerKay Sievers <kay.sievers@vrfy.org>2010-09-28 11:51:24 +0200
commitfd5bf055acae23a5ff0fcce8425675703f7bf5e0 (patch)
treea9bb6542444703af2bc9eddfa805f5d7be9b38fb /src
parent915d22e4f09e8f6d7fb2e7a7456f8b5908bd7f98 (diff)
use .conf for new config files: locale, vconsole, modules.d
Diffstat (limited to 'src')
-rw-r--r--src/locale-setup.c6
-rw-r--r--src/modules-load.c4
-rw-r--r--src/vconsole-setup.c6
3 files changed, 8 insertions, 8 deletions
diff --git a/src/locale-setup.c b/src/locale-setup.c
index 78fa2123f8..ffb4ee999e 100644
--- a/src/locale-setup.c
+++ b/src/locale-setup.c
@@ -93,9 +93,9 @@ int locale_setup(void) {
}
/* Hmm, nothing set on the kernel cmd line? Then let's
- * try /etc/locale */
+ * try /etc/locale.conf */
if (r <= 0 &&
- (r = parse_env_file("/etc/locale", NEWLINE,
+ (r = parse_env_file("/etc/locale.conf", NEWLINE,
"LANG", &variables[VARIABLE_LANG],
"LC_CTYPE", &variables[VARIABLE_LC_CTYPE],
"LC_NUMERIC", &variables[VARIABLE_LC_NUMERIC],
@@ -112,7 +112,7 @@ int locale_setup(void) {
NULL)) < 0) {
if (r != -ENOENT)
- log_warning("Failed to read /etc/locale: %s", strerror(-r));
+ log_warning("Failed to read /etc/locale.conf: %s", strerror(-r));
}
#ifdef TARGET_FEDORA
diff --git a/src/vconsole-setup.c b/src/vconsole-setup.c
index 047a153b87..9e5d65da65 100644
--- a/src/vconsole-setup.c
+++ b/src/vconsole-setup.c
@@ -186,9 +186,9 @@ int main(int argc, char **argv) {
}
/* Hmm, nothing set on the kernel cmd line? Then let's
- * try /etc/vconsole */
+ * try /etc/vconsole.conf */
if (r <= 0 &&
- (r = parse_env_file("/etc/vconsole", NEWLINE,
+ (r = parse_env_file("/etc/vconsole.conf", NEWLINE,
"KEYMAP", &vc_keymap,
"FONT", &vc_font,
"FONT_MAP", &vc_font_map,
@@ -196,7 +196,7 @@ int main(int argc, char **argv) {
NULL)) < 0) {
if (r != -ENOENT)
- log_warning("Failed to read /etc/vconsole: %s", strerror(-r));
+ log_warning("Failed to read /etc/vconsole.conf: %s", strerror(-r));
}
if (r <= 0) {
diff --git a/src/modules-load.c b/src/modules-load.c
index bfe5b8a995..56f2a907f4 100644
--- a/src/modules-load.c
+++ b/src/modules-load.c
@@ -31,7 +31,7 @@
#include "util.h"
#include "strv.h"
/* This reads all module names listed in /etc/modules.d/?*.modules and
* loads them into the kernel. This follows roughly Debian's way to
* handle modules, but uses a directory of fragments instead of a
* single /etc/modules file. */
@@ -46,7 +46,7 @@ static int scandir_filter(const struct dirent *d) {
d->d_type != DT_LNK)
return 0;
- return endswith(d->d_name, ".modules");
+ return endswith(d->d_name, ".conf");
}
int main(int argc, char *argv[]) {
@@ -31,7 +31,7 @@
#include "util.h"
#include "strv.h"
-/* This reads all module names listed in /etc/modules.d/?*.modules and
+/* This reads all module names listed in /etc/modules.d/?*.conf and
* loads them into the kernel. This follows roughly Debian's way to
* handle modules, but uses a directory of fragments instead of a